getEvents abstract method
Retrieves a list of events based on the provided query parameters.
Accepts an ExtractQueryParams object and returns an EventsGetResponse.
Implementation
Future<EventsGetResponse> getEvents(ExtractQueryParams queryParams);
Retrieves a list of events based on the provided query parameters.
Accepts an ExtractQueryParams object and returns an EventsGetResponse.
Future<EventsGetResponse> getEvents(ExtractQueryParams queryParams);